@@ -162,19 +162,21 @@ class ClockEvent(object):
             self._is_triggered = False
             return False
 
+        # if it's a trigger, allow to retrigger inside the callback
+        if not self.loop:
+            self._is_triggered = False
+
         # call the callback
         ret = callback(self._dt)
 
         # if it's a once event, don't care about the result
         # just remove the event
         if not self.loop:
-            self._is_triggered = False
             return False
 
         # if the user returns False explicitly,
         # remove the event
         if ret is False:
-            self._is_triggered = False
             return False
 
         return True
@@ -330,7 +332,7 @@ class ClockBase(object):
             cid = _hash(callback)
             if cid in events:
                 for event in events[cid][:]:
-                    if event.get_callback() is callback:
+                    if event.get_callback() == callback:
                         events[cid].remove(event)
 
     def _release_references(self):
@@ -381,7 +383,8 @@ class ClockBase(object):
 
         if count != self.max_iteration - 1:
             i = self.max_iteration - count + 1
-            Logger.trace('Clock: we done %d iteration before the frame' % i)
+            if __debug__:
+                Logger.trace('Clock: we done %d iteration before the frame' % i)
 
 
 if 'KIVY_DOC_INCLUDE' in environ:
