@@ -408,6 +408,26 @@ Or more complex::
         canvas:
             Color:
                 rgba: ut.get_random_color()
+
+set <key> <expr>
+~~~~~~~~~~~~~~~
+
+.. versionadded:: 1.0.6
+
+Syntax::
+
+    #:set <key> <expr>
+
+Set a key that will be available anywhere in the kv. For example::
+
+    #:set my_color (.4, .3, .4)
+    #:set my_color_hl (.5, .4, .5)
+
+    <Rule>:
+        state: 'normal'
+        canvas:
+            Color:
+                rgb: my_color if self.state == 'normal' else my_color_hl
 '''
 
 __all__ = ('Builder', 'BuilderBase', 'Parser')
@@ -470,10 +490,24 @@ class Parser(object):
     def execute_directives(self):
         for ln, cmd in self.directives:
             cmd = cmd.strip()
-            trace('Parser: got directive <%s>' % cmd)
+            if __debug__:
+                trace('Parser: got directive <%s>' % cmd)
             if cmd.startswith('kivy '):
                 # FIXME move the version checking here
                 continue
+            elif cmd.startswith('set '):
+                try:
+                    name, value = cmd[4:].strip().split(' ', 1)
+                except:
+                    Logger.exception('')
+                    raise ParserError(self, ln, 'Invalid directive syntax')
+                try:
+                    value = eval(value)
+                except:
+                    Logger.exception('')
+                    raise ParserError(self, ln, 'Invalid value')
+                global_idmap[name] = value
+
             elif cmd.startswith('import '):
                 package = cmd[7:].strip()
                 l = package.split(' ')
@@ -505,7 +539,8 @@ class Parser(object):
         lines = zip(range(num_lines), lines)
         self.sourcecode = lines[:]
 
-        trace('Parser: parsing %d lines' % num_lines)
+        if __debug__:
+            trace('Parser: parsing %d lines' % num_lines)
 
         # Ensure the version
         if self.filename:
@@ -544,7 +579,8 @@ class Parser(object):
         if version != '1.0':
             raise ParserError(self, ln, 'Only Kivy language 1.0 is supported'
                           ' (<%s> found)' % version)
-        trace('Parser: Kivy version is %s' % version)
+        if __debug__:
+            trace('Parser: Kivy version is %s' % version)
 
     def strip_comments(self, lines):
         '''Remove all comments from all lines in-place.
@@ -656,7 +692,8 @@ class Parser(object):
     def load_resource(self, filename):
         '''Load an external resource
         '''
-        trace('Parser: load external <%s>' % filename)
+        if __debug__:
+            trace('Parser: load external <%s>' % filename)
         with open(filename, 'r') as fd:
             return fd.read()
 
@@ -697,9 +734,12 @@ def create_handler(element, key, value, idmap):
     c_value = compile(value, '<string>', 'eval')
 
     def call_fn(sender, _value):
-        #trace('Builder: call_fn %s, key=%s, value=%s' % (element, key, value))
+        if __debug__:
+            trace('Builder: call_fn %s, key=%s, value=%s' % (
+                element, key, value))
         e_value = eval(c_value, _eval_globals, idmap)
-        #trace('Builder: call_fn => value=%s' % str(e_value))
+        if __debug__:
+            trace('Builder: call_fn => value=%s' % str(e_value))
         setattr(element, key, e_value)
 
     # bind every key.value
@@ -788,11 +828,13 @@ class BuilderBase(object):
         self.listwidget = []
 
     def add_rule(self, rule, defs):
-        trace('Builder: adding rule %s' % str(rule))
+        if __debug__:
+            trace('Builder: adding rule %s' % str(rule))
         self.rules.append((rule, defs))
 
     def add_template(self, name, cls, defs):
-        trace('Builder: adding template %s' % str(name))
+        if __debug__:
+            trace('Builder: adding template %s' % str(name))
         if name in self.templates:
             raise Exception('The template <%s> already exist' % name)
         self.templates[name] = (cls, defs)
@@ -805,7 +847,8 @@ class BuilderBase(object):
                 If True, the Builder will raise an exception if you have a root
                 widget inside the definition.
         '''
-        trace('Builder: load file %s' % filename)
+        if __debug__:
+            trace('Builder: load file %s' % filename)
         with open(filename, 'r') as fd:
             kwargs['filename'] = filename
             return self.load_string(fd.read(), **kwargs)
@@ -840,7 +883,8 @@ class BuilderBase(object):
         '''Apply all the Kivy rules matching the widget on the widget.
         '''
         matches = self.match(widget)
-        trace('Builder: Found %d matches for %s' % (len(matches), widget))
+        if __debug__:
+            trace('Builder: Found %d matches for %s' % (len(matches), widget))
         if not matches:
             return
         self._push_widgets()
@@ -939,7 +983,8 @@ class BuilderBase(object):
         is_template = False
 
         if is_rule is False:
-            trace('Builder: build item %s' % item)
+            if __debug__:
+                trace('Builder: build item %s' % item)
             if item.startswith('<'):
                 raise ParserError(params['__ctx__'], params['__line__'],
                                'Rules are not accepted inside widgets')
@@ -956,7 +1001,11 @@ class BuilderBase(object):
                 is_template = True
                 self._push_widgets()
             else:
-                widget = cls(__no_builder=True)
+                try:
+                    widget = cls(__no_builder=True)
+                except Exception, e:
+                    raise ParserError(params['__ctx__'], params['__line__'],
+                                      str(e))
                 if not no_apply:
                     self.listwidget.append(widget)
         else:
@@ -965,14 +1014,21 @@ class BuilderBase(object):
         if is_template:
             # checking reserved keyword
             ctx = {}
+            template_id = None
             for key, value in self._iterate(params):
+                if key == 'id':
+                    template_id = value[0]
+                    continue
                 if key == 'children':
                     raise ParserError(params['__ctx__'], params['__line__'],
                            'Children in template are forbidden')
                 if key in ('canvas.before', 'canvas', 'canvas.after'):
                     raise ParserError(params['__ctx__'], params['__line__'],
                            'Canvas instruction in template are forbidden')
-                ctx[key] = eval(value[0], _eval_globals, self.idmap)
+                try:
+                    ctx[key] = eval(value[0], _eval_globals, self.idmap)
+                except Exception, e:
+                    raise ParserError(params['__ctx__'], params['__line__'], e)
             widget = cls(**ctx)
         else:
             self.idmap['self'] = widget
@@ -1015,10 +1071,12 @@ class BuilderBase(object):
                                             copy(self.idmap)))
 
         self._pop_ids()
-        if is_rule:
-            self.build_attributes()
         if is_template:
             self._pop_widgets()
+            if template_id:
+                self.gidmap[template_id] = widget
+        if is_rule:
+            self.build_attributes()
 
         return widget
 
@@ -1047,7 +1105,8 @@ class BuilderBase(object):
 
     def build_handler(self, element, key, value, idmap, is_widget):
         if key.startswith('on_'):
-            trace('Builder: create custom callback for ' + key)
+            if __debug__:
+                trace('Builder: create custom callback for ' + key)
             if not element.is_event_type(key):
                 key = key[3:]
             element.bind(**{key: partial(custom_callback, (
@@ -1055,13 +1114,15 @@ class BuilderBase(object):
 
         else:
             value = create_handler(element, key, value, idmap)
-            trace('Builder: set %s=%s for %s' % (key, value, element))
+            if __debug__:
+                trace('Builder: set %s=%s for %s' % (key, value, element))
             if is_widget and not hasattr(element, key):
                     element.create_property(key)
             setattr(element, key, value)
 
     def build_canvas(self, canvas, item, elements):
-        trace('Builder: build canvas for %s' % item)
+        if __debug__:
+            trace('Builder: build canvas for %s' % item)
         for name, params in elements:
             if name == 'Clear':
                 canvas.clear()
@@ -1079,7 +1140,8 @@ class BuilderBase(object):
                     raise
 
     def build_rule(self, item, params):
-        trace('Builder: build rule for %s' % item)
+        if __debug__:
+            trace('Builder: build rule for %s' % item)
         if item[0] != '<' or item[-1] != '>':
             raise ParserError(params['__ctx__'], params['__line__'],
                            'Invalid rule (must be inside <>)')
@@ -1098,7 +1160,8 @@ class BuilderBase(object):
             self.add_rule(crule, params)
 
     def build_template(self, item, params):
-        trace('Builder: build template for %s' % item)
+        if __debug__:
+            trace('Builder: build template for %s' % item)
         if item[0] != '[' or item[-1] != ']':
             raise ParserError(params['__ctx__'], params['__line__'],
                 'Invalid template (must be inside [])')
